@@ -1,5 +1,7 @@
 #[cfg(feature = "derive")]
 pub use actix_telepathy_derive::*;
+#[cfg(feature = "protocols")]
+pub mod protocols;
 
 mod network;
 mod codec;
@@ -24,4 +26,4 @@ pub mod prelude {
     pub use crate::remote::{RemoteMessage, RemoteAddr, RemoteWrapper, AnyAddr, RemoteActor};
     pub use crate::serialization::{DefaultSerialization, CustomSerialization};
     pub use crate::network::NetworkInterface;
-}
\ No newline at end of file
+}
