@@ -5,9 +5,11 @@ pub trait RemoteActor
 where
     Self: Actor + Handler<RemoteWrapper>
 {
-    fn register(&mut self, rec: Recipient<RemoteWrapper>, identifier: String) {
+    const ACTOR_ID: &'static str;
+
+    fn register(&mut self, rec: Recipient<RemoteWrapper>) {
         AddrResolver::from_registry().do_send(
-            AddrRequest::Register(rec, identifier)
+            AddrRequest::Register(rec, Self::ACTOR_ID.to_string())
         );
     }
 }
