@@ -1,6 +1,8 @@
 mod addr;
 mod message;
 mod actor;
+#[cfg(test)]
+mod tests;
 
 pub use addr::resolver::{AddrRepresentation, AddrRequest, AddrResolver, AddrResponse};
 pub use self::addr::{AnyAddr, RemoteAddr};
